==> ws-v3.50.4-src.tar.gz: ws-v3.50-4/src/sheet/Japanese.cpp <==
  WSGIappLocaleSet()->setLocaleString("EUCJP","","");
  WSGIappLocaleSet()->setLocaleString("EUCJP","p1:WSSTR Row Counter", "Կ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","p1:WSSTR Column Counter", "");
  WSGIappLocaleSet()->setLocaleString("EUCJP","p1:WSSTR Fixed Row Counter", "Կ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","p1:WSSTR Fixed Column Counter","");
  WSGIappLocaleSet()->setLocaleString("EUCJP","p1:WSSTR Grid Line Type","åɥ饤μ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","p1:WSSTR Cell Default Width","ʵ͡");
  WSGIappLocaleSet()->setLocaleString("EUCJP","p1:WSSTR Cell Default Height","ѥι⤵ʵ͡");
  WSGIappLocaleSet()->setLocaleString("EUCJP","p1:WSSTR Fixed Cell Height","ꥻι⤵ʵ͡");
  WSGIappLocaleSet()->setLocaleString("EUCJP","p1:WSSTR Cell Default Font No.","ѥΥեȡʵ͡");
  WSGIappLocaleSet()->setLocaleString("EUCJP","p1:WSSTR Fixed Cell Default Font No.","ꥻΥե");
  WSGIappLocaleSet()->setLocaleString("EUCJP","p1:WSSTR Edit Enabled", "Խ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","p1:WSSTR Fixed Cell Horizontal number drawing","ֹɽ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","p1:WSSTR Fixed Cell Vertical number drawing","ιֹɽ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","p1:WSSTR Sheet Back Color","Ȥطʿ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","p1:WSSTR Cell Default Back Color","ѥطʿʵ͡");
  WSGIappLocaleSet()->setLocaleString("EUCJP","p1:WSSTR Cell Default Text Color","ѥʸʵ͡");
  WSGIappLocaleSet()->setLocaleString("EUCJP","p1:WSSTR Fixed Cell Back Color","ꥻطʿ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","p1:WSSTR Fixed Cell Text Color","ꥻʸ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","p1:WSSTR Grid Color","åɤο");
  WSGIappLocaleSet()->setLocaleString("EUCJP","p1:WSSTR DB Select Item","ǡ١");
  WSGIappLocaleSet()->setLocaleString("EUCJP","p1:WSSTR DB Sort Item1","ȹܣ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","p1:WSSTR DB Sort1","Ⱦ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","p1:WSSTR DB Sort Item2","ȹܣ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","p1:WSSTR DB Sort2","Ⱦ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","p1:WSSTR DB Sort Item3","ȹܣ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","p1:WSSTR DB Sort3","Ⱦ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","p1:WSSTR DB Select SQL","SQLʸ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","X:WSSTR ASC","");
  WSGIappLocaleSet()->setLocaleString("EUCJP","X:WSSTR DESC","߽");

  WSGIappLocaleSet()->setLocaleString("EUCJP","X:WSSTR None","ʤ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","X:WSSTR Horz","ʿ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","X:WSSTR Vert","ľ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","X:WSSTR Both","ξ");

==> ws-v3.70.8-src.tar.gz: ws-v3.70-8/src/sheet/Japanese.cpp <==
  WSGIappLocaleSet()->setLocaleString("EUCJP","","");
  WSGIappLocaleSet()->setLocaleString("EUCJP","p1:WSSTR Row Counter", "Կ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","p1:WSSTR Column Counter", "");
  WSGIappLocaleSet()->setLocaleString("EUCJP","p1:WSSTR Fixed Row Counter", "Կ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","p1:WSSTR Fixed Column Counter","");
  WSGIappLocaleSet()->setLocaleString("EUCJP","p1:WSSTR Grid Line Type","åɥ饤μ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","p1:WSSTR Cell Default Width","ʵ͡");
  WSGIappLocaleSet()->setLocaleString("EUCJP","p1:WSSTR Cell Default Height","ѥι⤵ʵ͡");
  WSGIappLocaleSet()->setLocaleString("EUCJP","p1:WSSTR Fixed Cell Height","ꥻι⤵ʵ͡");
  WSGIappLocaleSet()->setLocaleString("EUCJP","p1:WSSTR Cell Default Font No.","ѥΥեȡʵ͡");
  WSGIappLocaleSet()->setLocaleString("EUCJP","p1:WSSTR Fixed Cell Default Font No.","ꥻΥե");
  WSGIappLocaleSet()->setLocaleString("EUCJP","p1:WSSTR Edit Enabled", "Խ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","p1:WSSTR Fixed Cell Horizontal number drawing","ֹɽ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","p1:WSSTR Fixed Cell Vertical number drawing","ιֹɽ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","p1:WSSTR Sheet Back Color","Ȥطʿ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","p1:WSSTR Cell Default Back Color","ѥطʿʵ͡");
  WSGIappLocaleSet()->setLocaleString("EUCJP","p1:WSSTR Cell Default Text Color","ѥʸʵ͡");
  WSGIappLocaleSet()->setLocaleString("EUCJP","p1:WSSTR Fixed Cell Back Color","ꥻطʿ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","p1:WSSTR Fixed Cell Text Color","ꥻʸ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","p1:WSSTR Grid Color","åɤο");
  WSGIappLocaleSet()->setLocaleString("EUCJP","p1:WSSTR DB Select Item","ǡ١");
  WSGIappLocaleSet()->setLocaleString("EUCJP","p1:WSSTR DB Sort Item1","ȹܣ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","p1:WSSTR DB Sort1","Ⱦ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","p1:WSSTR DB Sort Item2","ȹܣ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","p1:WSSTR DB Sort2","Ⱦ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","p1:WSSTR DB Sort Item3","ȹܣ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","p1:WSSTR DB Sort3","Ⱦ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","p1:WSSTR DB Select SQL","SQLʸ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","X:WSSTR ASC","");
  WSGIappLocaleSet()->setLocaleString("EUCJP","X:WSSTR DESC","߽");

  WSGIappLocaleSet()->setLocaleString("EUCJP","X:WSSTR None","ʤ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","X:WSSTR Horz","ʿ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","X:WSSTR Vert","ľ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","X:WSSTR Both","ξ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","p1:WSSTR DB Cell Auto Resize","ǡ١³˥μưĴ");
  WSGIappLocaleSet()->setLocaleString("EUCJP","p1:WSSTR DB Cell Title","ǡ١³˥Υȥưɽ");
